// This file is generated by kconfig_compiler_kf5 from krfb.kcfg.
// All changes you do to this file will be lost.
#ifndef KRFBCONFIG_H
#define KRFBCONFIG_H

#include <kconfigskeleton.h>
#include <QCoreApplication>
#include <QDebug>

class KrfbConfig : public KConfigSkeleton
{
  public:

    static KrfbConfig *self();
    ~KrfbConfig();


    /**
      Get Start minimized
    */
    static
    bool startMinimized()
    {
      return self()->mStartMinimized;
    }


    /**
      Get Use the default port for VNC (5900)
    */
    static
    bool useDefaultPort()
    {
      return self()->mUseDefaultPort;
    }


    /**
      Get This is the port on which krfb will listen.
    */
    static
    int port()
    {
      return self()->mPort;
    }


    /**
      Get Announce the service on the local network
    */
    static
    bool publishService()
    {
      return self()->mPublishService;
    }


    /**
      Get Do not store passwords in KWallet
    */
    static
    bool noWallet()
    {
      return self()->mNoWallet;
    }


    /**
      Get Allow remote connections to manage the desktop.
    */
    static
    bool allowDesktopControl()
    {
      return self()->mAllowDesktopControl;
    }


    /**
      Get Allow connections without an invitation.
    */
    static
    bool allowUnattendedAccess()
    {
      return self()->mAllowUnattendedAccess;
    }


    /**
      Get Password for uninvited connections.
    */
    static
    QString unattendedAccessPassword()
    {
      return self()->mUnattendedAccessPassword;
    }


    /**
      Get Password for uninvited connections.
    */
    static
    QString desktopSharingPassword()
    {
      return self()->mDesktopSharingPassword;
    }


    /**
      Get Preferred Frame Buffer Plugin
    */
    static
    QString preferredFrameBufferPlugin()
    {
      return self()->mPreferredFrameBufferPlugin;
    }

  protected:
    KrfbConfig();
    friend class KrfbConfigHelper;


    // MainWindow
    bool mStartMinimized;

    // TCP
    bool mUseDefaultPort;
    int mPort;
    bool mPublishService;

    // Security
    bool mNoWallet;
    bool mAllowDesktopControl;
    bool mAllowUnattendedAccess;
    QString mUnattendedAccessPassword;
    QString mDesktopSharingPassword;

    // FrameBuffer
    QString mPreferredFrameBufferPlugin;

  private:
};

#endif

