#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'configtcp.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CONFIGTCP_H
#define UI_CONFIGTCP_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QSpinBox>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_TCP
{
public:
    QVBoxLayout *vboxLayout;
    QCheckBox *kcfg_publishService;
    QCheckBox *kcfg_useDefaultPort;
    QHBoxLayout *hboxLayout;
    QLabel *label;
    QSpinBox *kcfg_port;

    void setupUi(QWidget *TCP)
    {
        if (TCP->objectName().isEmpty())
            TCP->setObjectName(QStringLiteral("TCP"));
        TCP->resize(400, 169);
        vboxLayout = new QVBoxLayout(TCP);
#ifndef UI_Q_OS_MAC
        vboxLayout->setSpacing(6);
#endif
#ifndef UI_Q_OS_MAC
        vboxLayout->setContentsMargins(9, 9, 9, 9);
#endif
        vboxLayout->setObjectName(QStringLiteral("vboxLayout"));
        kcfg_publishService = new QCheckBox(TCP);
        kcfg_publishService->setObjectName(QStringLiteral("kcfg_publishService"));
        kcfg_publishService->setChecked(true);

        vboxLayout->addWidget(kcfg_publishService);

        kcfg_useDefaultPort = new QCheckBox(TCP);
        kcfg_useDefaultPort->setObjectName(QStringLiteral("kcfg_useDefaultPort"));
        kcfg_useDefaultPort->setChecked(true);

        vboxLayout->addWidget(kcfg_useDefaultPort);

        hboxLayout = new QHBoxLayout();
#ifndef UI_Q_OS_MAC
        hboxLayout->setSpacing(6);
#endif
        hboxLayout->setContentsMargins(0, 0, 0, 0);
        hboxLayout->setObjectName(QStringLiteral("hboxLayout"));
        label = new QLabel(TCP);
        label->setObjectName(QStringLiteral("label"));

        hboxLayout->addWidget(label);

        kcfg_port = new QSpinBox(TCP);
        kcfg_port->setObjectName(QStringLiteral("kcfg_port"));
        kcfg_port->setEnabled(false);
        kcfg_port->setMaximum(65535);

        hboxLayout->addWidget(kcfg_port);


        vboxLayout->addLayout(hboxLayout);

#ifndef UI_QT_NO_SHORTCUT
        label->setBuddy(kcfg_port);
#endif // QT_NO_SHORTCUT
        QWidget::setTabOrder(kcfg_useDefaultPort, kcfg_port);

        retranslateUi(TCP);
        QObject::connect(kcfg_useDefaultPort, SIGNAL(toggled(bool)), kcfg_port, SLOT(setDisabled(bool)));

        QMetaObject::connectSlotsByName(TCP);
    } // setupUi

    void retranslateUi(QWidget *TCP)
    {
        kcfg_publishService->setText(tr2i18n("Announce the service on the local network", Q_NULLPTR));
        kcfg_useDefaultPort->setText(tr2i18n("Use default port", Q_NULLPTR));
        label->setText(tr2i18n("Listening port:", Q_NULLPTR));
        Q_UNUSED(TCP);
    } // retranslateUi

};

namespace Ui {
    class TCP: public Ui_TCP {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CONFIGTCP_H

