#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'configsecurity.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CONFIGSECURITY_H
#define UI_CONFIGSECURITY_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QCheckBox>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_Security
{
public:
    QVBoxLayout *vboxLayout;
    QCheckBox *kcfg_allowDesktopControl;
    QSpacerItem *spacerItem;

    void setupUi(QWidget *Security)
    {
        if (Security->objectName().isEmpty())
            Security->setObjectName(QStringLiteral("Security"));
        Security->resize(507, 201);
        vboxLayout = new QVBoxLayout(Security);
        vboxLayout->setObjectName(QStringLiteral("vboxLayout"));
        kcfg_allowDesktopControl = new QCheckBox(Security);
        kcfg_allowDesktopControl->setObjectName(QStringLiteral("kcfg_allowDesktopControl"));
        kcfg_allowDesktopControl->setChecked(true);

        vboxLayout->addWidget(kcfg_allowDesktopControl);

        spacerItem = new QSpacerItem(20, 40, QSizePolicy::Minimum, QSizePolicy::Expanding);

        vboxLayout->addItem(spacerItem);


        retranslateUi(Security);

        QMetaObject::connectSlotsByName(Security);
    } // setupUi

    void retranslateUi(QWidget *Security)
    {
        kcfg_allowDesktopControl->setText(tr2i18n("Allow remote connections to control your desktop", Q_NULLPTR));
        Q_UNUSED(Security);
    } // retranslateUi

};

namespace Ui {
    class Security: public Ui_Security {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CONFIGSECURITY_H

