#include <klocalizedstring.h>

/********************************************************************************
** Form generated from reading UI file 'configframebuffer.ui'
**
** Created by: Qt User Interface Compiler version 5.9.4
**
** WARNING! All changes made in this file will be lost when recompiling UI file!
********************************************************************************/

#ifndef UI_CONFIGFRAMEBUFFER_H
#define UI_CONFIGFRAMEBUFFER_H

#include <QtCore/QVariant>
#include <QtWidgets/QAction>
#include <QtWidgets/QApplication>
#include <QtWidgets/QButtonGroup>
#include <QtWidgets/QComboBox>
#include <QtWidgets/QHBoxLayout>
#include <QtWidgets/QHeaderView>
#include <QtWidgets/QLabel>
#include <QtWidgets/QLineEdit>
#include <QtWidgets/QSpacerItem>
#include <QtWidgets/QVBoxLayout>
#include <QtWidgets/QWidget>

QT_BEGIN_NAMESPACE

class Ui_Framebuffer
{
public:
    QVBoxLayout *verticalLayout;
    QHBoxLayout *horizontalLayout;
    QLabel *label;
    QComboBox *cb_preferredFrameBufferPlugin;
    QLineEdit *kcfg_preferredFrameBufferPlugin;
    QLabel *helpText;
    QSpacerItem *verticalSpacer;

    void setupUi(QWidget *Framebuffer)
    {
        if (Framebuffer->objectName().isEmpty())
            Framebuffer->setObjectName(QStringLiteral("Framebuffer"));
        Framebuffer->resize(418, 186);
        verticalLayout = new QVBoxLayout(Framebuffer);
        verticalLayout->setObjectName(QStringLiteral("verticalLayout"));
        horizontalLayout = new QHBoxLayout();
        horizontalLayout->setObjectName(QStringLiteral("horizontalLayout"));
        label = new QLabel(Framebuffer);
        label->setObjectName(QStringLiteral("label"));

        horizontalLayout->addWidget(label);

        cb_preferredFrameBufferPlugin = new QComboBox(Framebuffer);
        cb_preferredFrameBufferPlugin->setObjectName(QStringLiteral("cb_preferredFrameBufferPlugin"));
        cb_preferredFrameBufferPlugin->setEditable(false);

        horizontalLayout->addWidget(cb_preferredFrameBufferPlugin);

        kcfg_preferredFrameBufferPlugin = new QLineEdit(Framebuffer);
        kcfg_preferredFrameBufferPlugin->setObjectName(QStringLiteral("kcfg_preferredFrameBufferPlugin"));

        horizontalLayout->addWidget(kcfg_preferredFrameBufferPlugin);


        verticalLayout->addLayout(horizontalLayout);

        helpText = new QLabel(Framebuffer);
        helpText->setObjectName(QStringLiteral("helpText"));
        helpText->setEnabled(true);
        helpText->setTextFormat(Qt::RichText);
        helpText->setScaledContents(false);
        helpText->setAlignment(Qt::AlignLeading|Qt::AlignLeft|Qt::AlignVCenter);
        helpText->setWordWrap(true);
        helpText->setMargin(5);
        helpText->setTextInteractionFlags(Qt::NoTextInteraction);

        verticalLayout->addWidget(helpText);

        verticalSpacer = new QSpacerItem(20, 63, QSizePolicy::Minimum, QSizePolicy::Expanding);

        verticalLayout->addItem(verticalSpacer);

#ifndef UI_QT_NO_SHORTCUT
        label->setBuddy(cb_preferredFrameBufferPlugin);
#endif // QT_NO_SHORTCUT
        QWidget::setTabOrder(cb_preferredFrameBufferPlugin, kcfg_preferredFrameBufferPlugin);

        retranslateUi(Framebuffer);

        QMetaObject::connectSlotsByName(Framebuffer);
    } // setupUi

    void retranslateUi(QWidget *Framebuffer)
    {
        Framebuffer->setWindowTitle(tr2i18n("Framebuffer", Q_NULLPTR));
        label->setText(tr2i18n("Preferred frameb&uffer plugin:", Q_NULLPTR));
        helpText->setText(tr2i18n("<html><head/><body><p>When using x11, <span style=\" font-weight:600;\">xcb</span> plugin should be preferred, because it is more performant.<br/><span style=\" font-weight:600;\">qt</span> plugin is a safe fallback, if for some reason others don't work. But also it is very slow.</p></body></html>", Q_NULLPTR));
    } // retranslateUi

};

namespace Ui {
    class Framebuffer: public Ui_Framebuffer {};
} // namespace Ui

QT_END_NAMESPACE

#endif // CONFIGFRAMEBUFFER_H

